DistinguishedName

Struct DistinguishedName 

#[non_exhaustive]
pub struct DistinguishedName { pub country_name: Option<String>, pub state_or_province_name: Option<String>, pub locality_name: Option<String>, pub organization_name: Option<String>, pub organizational_unit_name: Option<String>, pub common_name: String, pub email_address: Option<String>, pub subject_alt_names: Option<Vec<String>>, }
DistinguishedName : Data used for creation of CSRs. If subjectAltNames is omitted, it is set to the same value as commonName. If it is set to an empty list, no SAN Extension is added. All SANs are considered DNS names, unless they start with "IP:" to signal IP names.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
country_name: Option<String>state_or_province_name: Option<String>locality_name: Option<String>organization_name: Option<String>organizational_unit_name: Option<String>common_name: Stringemail_address: Option<String>subject_alt_names: Option<Vec<String>>

Implementations



impl DistinguishedName

pub fn new(common_name: String) -> DistinguishedName

Data used for creation of CSRs. If subjectAltNames is omitted, it is set to the same value as commonName. If it is set to an empty list, no SAN Extension is added. All SANs are considered DNS names, unless they start with "IP:" to signal IP names.